@@ -4,7 +4,7 @@
 # treelocalcontrol.py, provides a class for the main tree commands
 #
 # TreeLine, an information storage program
-# Copyright (C) 2019, Douglas W. Bell
+# Copyright (C) 2025, Douglas W. Bell
 #
 # This is free software; you can redistribute it and/or modify it under the
 # terms of the GNU General Public License, either Version 2 or any later
@@ -17,11 +17,13 @@ import json
 import os
 import sys
 import gzip
+import datetime
 import operator
 from itertools import chain
-from PyQt5.QtCore import QObject, QTimer, Qt, pyqtSignal
-from PyQt5.QtWidgets import (QAction, QActionGroup, QApplication, QDialog,
-                             QFileDialog, QMenu, QMessageBox)
+from PyQt6.QtCore import QObject, QTimer, Qt, pyqtSignal
+from PyQt6.QtGui import QAction, QActionGroup
+from PyQt6.QtWidgets import (QApplication, QDialog, QFileDialog, QMenu,
+                             QMessageBox)
 import treemaincontrol
 import treestructure
 import treemodel
@@ -46,7 +48,7 @@ class TreeLocalControl(QObject):
     controlActivated = pyqtSignal(QObject)
     controlClosed = pyqtSignal(QObject)
     def __init__(self, allActions, fileObj=None, treeStruct=None,
-                 forceNewWindow=False, parent=None):
+                 fileModTime=None, forceNewWindow=False, parent=None):
         """Initialize the local tree controls.
 
         Use an imported structure if given or open the file if path is given.
@@ -55,6 +57,7 @@ class TreeLocalControl(QObject):
             allActions -- a dict containing the upper level actions
             fileObj -- the path object or file object to open, if given
             treeStruct -- an imported tree structure file, if given
+            fileModTime -- file modified time for external modification checks
             forceNewWindow -- if True, use a new window regardless of option
             parent -- a parent object if given
         """
@@ -63,6 +66,7 @@ class TreeLocalControl(QObject):
         self.spellCheckLang = ''
         self.allActions = allActions.copy()
         self.setupActions()
+        self.fileModTime = fileModTime
         self.filePathObj = (pathlib.Path(fileObj.name) if
                             hasattr(fileObj, 'read') else fileObj)
         if treeStruct:
@@ -176,7 +180,7 @@ class TreeLocalControl(QObject):
         Arguments:
             setModified -- if True, set the modified flag for this file
         """
-        QApplication.setOverrideCursor(Qt.WaitCursor)
+        QApplication.setOverrideCursor(Qt.CursorShape.WaitCursor)
         typeChanges = 0
         if self.structure.treeFormats.conditionalTypes:
             for node in self.structure.childList:
@@ -193,14 +197,17 @@ class TreeLocalControl(QObject):
             self.setModified()
         QApplication.restoreOverrideCursor()
 
-    def updateRightViews(self, setModified=False):
+    def updateRightViews(self, setModified=False, otherTrees=False):
         """Update the right-hand views in all windows.
 
         Arguments:
             setModified -- if True, set the modified flag for this file
+            otherTrees -- if True, also update trees in non-active windows
         """
         for window in self.windowList:
             window.updateRightViews()
+            if otherTrees and window != self.activeWindow:
+                window.updateTree()
         if setModified:
             self.setModified()
 
@@ -210,7 +217,7 @@ class TreeLocalControl(QObject):
         Arguments:
             setModified -- if True, set the modified flag for this file
         """
-        QApplication.setOverrideCursor(Qt.WaitCursor)
+        QApplication.setOverrideCursor(Qt.CursorShape.WaitCursor)
         if self.structure.treeFormats.conditionalTypes:
             for node in self.structure.childList:
                 node.setDescendantConditionalTypes(self.structure)
@@ -297,6 +304,8 @@ class TreeLocalControl(QObject):
             self.allActions['NodeMoveDown'].setEnabled(False)
             self.allActions['NodeMoveFirst'].setEnabled(False)
             self.allActions['NodeMoveLast'].setEnabled(False)
+        else:
+            self.allActions['NodeAddChild'].setEnabled(True)
         self.activeWindow.updateCommandsAvail()
 
     def updateWindowCaptions(self):
@@ -359,9 +368,9 @@ class TreeLocalControl(QObject):
         """
         if len(self.windowList) > 1:
             self.windowList.remove(window)
+            # set active to one not closing to avoid errors while changing
+            self.activeWindow = self.windowList[0]
             window.allowCloseFlag = True
-            # # keep ref until Qt window can fully close
-            # self.oldWindow = window
         elif self.checkSaveChanges():
             window.allowCloseFlag = True
             self.controlClosed.emit(self)
@@ -381,11 +390,13 @@ class TreeLocalControl(QObject):
                       if self.filePathObj else _('Save changes?'))
         ans = QMessageBox.information(self.activeWindow, 'TreeLine',
                                       promptText,
-                                      QMessageBox.Save | QMessageBox.Discard |
-                                      QMessageBox.Cancel, QMessageBox.Save)
-        if ans == QMessageBox.Save:
+                                      QMessageBox.StandardButton.Save |
+                                      QMessageBox.StandardButton.Discard |
+                                      QMessageBox.StandardButton.Cancel,
+                                      QMessageBox.StandardButton.Save)
+        if ans == QMessageBox.StandardButton.Save:
             self.fileSave()
-        elif ans == QMessageBox.Cancel:
+        elif ans == QMessageBox.StandardButton.Cancel:
             return False
         else:
             self.deleteAutoSaveFile()
@@ -688,6 +699,12 @@ class TreeLocalControl(QObject):
         formatUnderlineAct.setEnabled(False)
         localActions['FormatUnderlineFont'] = formatUnderlineAct
 
+        formatStrikethroughAct = QAction(_('St&rikethrough Font'), self,
+                statusTip=_('Set the current or selected font to strikethough'),
+                checkable=True)
+        formatStrikethroughAct.setEnabled(False)
+        localActions['FormatStrikethroughFont'] = formatStrikethroughAct
+
         title = _('&Font Size')
         key = globalref.keyboardOptions['FormatFontSize']
         if not key.isEmpty():
@@ -720,6 +737,11 @@ class TreeLocalControl(QObject):
         formatIntLinkAct.setEnabled(False)
         localActions['FormatIntLink'] = formatIntLinkAct
 
+        formatInsDateAct = QAction(_('Insert &Date'), self,
+                                   statusTip=_('Insert current date as text'))
+        formatInsDateAct.setEnabled(False)
+        localActions['FormatInsertDate'] = formatInsDateAct
+
         formatClearFormatAct =  QAction(_('Clear For&matting'), self,
                       statusTip=_('Clear current or selected text formatting'))
         formatClearFormatAct.setEnabled(False)
@@ -754,7 +776,18 @@ class TreeLocalControl(QObject):
         if not self.filePathObj or self.imported:
             self.fileSaveAs()
             return
-        QApplication.setOverrideCursor(Qt.WaitCursor)
+        if not backupFile and self.fileModTime:
+            fileSeconds = self.filePathObj.stat().st_mtime
+            storedSeconds = self.fileModTime.timestamp()
+            # check for an external file mod with a 10 second margin
+            if fileSeconds > storedSeconds + 10:
+                dialog = miscdialogs.ExtModDialog(datetime.datetime.
+                                                  fromtimestamp(fileSeconds),
+                                                  self.activeWindow)
+                if dialog.exec() != QDialog.DialogCode.Accepted:
+                    # user cancelled the save
+                    return
+        QApplication.setOverrideCursor(Qt.CursorShape.WaitCursor)
         savePathObj = self.filePathObj
         if backupFile:
             savePathObj = pathlib.Path(str(savePathObj) + '~')
@@ -787,9 +820,9 @@ class TreeLocalControl(QObject):
                     QApplication.restoreOverrideCursor()
                     dialog = miscdialogs.PasswordDialog(True, '',
                                                         self.activeWindow)
-                    if dialog.exec_() != QDialog.Accepted:
+                    if dialog.exec() != QDialog.DialogCode.Accepted:
                         return
-                    QApplication.setOverrideCursor(Qt.WaitCursor)
+                    QApplication.setOverrideCursor(Qt.CursorShape.WaitCursor)
                     password = dialog.password
                     if miscdialogs.PasswordDialog.remember:
                         globalref.mainControl.passwords[self.
@@ -807,6 +840,7 @@ class TreeLocalControl(QObject):
                 return
         QApplication.restoreOverrideCursor()
         if not backupFile:
+            self.fileModTime = datetime.datetime.now()
             fileInfoFormat = self.structure.treeFormats.fileInfoFormat
             fileInfoFormat.updateFileInfo(self.filePathObj,
                                           self.structure.fileInfoNode)
@@ -835,6 +869,7 @@ class TreeLocalControl(QObject):
                                                  str(defaultPathObj),
                                                  filters, initFilter))
         if newPath:
+            self.fileModTime = None
             self.filePathObj = pathlib.Path(newPath)
             if not self.filePathObj.suffix:
                 self.filePathObj = self.filePathObj.with_suffix('.trln')
@@ -871,7 +906,7 @@ class TreeLocalControl(QObject):
         """
         origZeroBlanks = self.structure.mathZeroBlanks
         dialog = miscdialogs.FilePropertiesDialog(self, self.activeWindow)
-        if dialog.exec_() == QDialog.Accepted:
+        if dialog.exec() == QDialog.DialogCode.Accepted:
             self.setModified()
             if self.structure.mathZeroBlanks != origZeroBlanks:
                 self.updateAll(False)
@@ -1238,7 +1273,7 @@ class TreeLocalControl(QObject):
                                            defaultPathObj(True)), filters)
         if not fileName:
             return
-        QApplication.setOverrideCursor(Qt.WaitCursor)
+        QApplication.setOverrideCursor(Qt.CursorShape.WaitCursor)
         newStructure = None
         try:
             with open(fileName, 'r', encoding='utf-8') as f:
@@ -1286,7 +1321,7 @@ class TreeLocalControl(QObject):
     def dataCloneMatches(self):
         """Convert all matching nodes into clones.
         """
-        QApplication.setOverrideCursor(Qt.WaitCursor)
+        QApplication.setOverrideCursor(Qt.CursorShape.WaitCursor)
         selSpots = self.currentSelectionModel().selectedSpots()
         titleDict = {}
         for node in self.structure.nodeDict.values():
@@ -1331,7 +1366,7 @@ class TreeLocalControl(QObject):
     def dataDetachClones(self):
         """Detach all cloned nodes in current branches.
         """
-        QApplication.setOverrideCursor(Qt.WaitCursor)
+        QApplication.setOverrideCursor(Qt.CursorShape.WaitCursor)
         selSpots = self.currentSelectionModel().selectedBranchSpots()
         undoObj = undo.ChildListUndo(self.structure.undoList,
                                      [spot.parentSpot.nodeRef for spot in
@@ -1364,7 +1399,7 @@ class TreeLocalControl(QObject):
 
         Overwrites data in any fields with the same name.
         """
-        QApplication.setOverrideCursor(Qt.WaitCursor)
+        QApplication.setOverrideCursor(Qt.CursorShape.WaitCursor)
         selectList = self.currentSelectionModel().selectedBranches()
         undo.ChildDataUndo(self.structure.undoList, selectList, True,
                             self.structure.treeFormats)
@@ -1390,9 +1425,9 @@ class TreeLocalControl(QObject):
         dialog = miscdialogs.FieldSelectDialog(_('Category Fields'),
                                               _('Select fields for new level'),
                                               fieldList, self.activeWindow)
-        if dialog.exec_() != QDialog.Accepted:
+        if dialog.exec() != QDialog.DialogCode.Accepted:
             return
-        QApplication.setOverrideCursor(Qt.WaitCursor)
+        QApplication.setOverrideCursor(Qt.CursorShape.WaitCursor)
         undo.ChildDataUndo(self.structure.undoList, selectList, True,
                            self.structure.treeFormats)
         for node in selectList:
@@ -1404,7 +1439,7 @@ class TreeLocalControl(QObject):
     def dataSwapCategory(self):
         """Swap child and grandchild category nodes.
         """
-        QApplication.setOverrideCursor(Qt.WaitCursor)
+        QApplication.setOverrideCursor(Qt.CursorShape.WaitCursor)
         selectList = self.currentSelectionModel().selectedBranches()
         undo.ChildListUndo(self.structure.undoList, selectList, addBranch=True)
         doneNodes = set()
@@ -1655,7 +1690,7 @@ class TreeLocalControl(QObject):
             fieldName -- if given, only find matches under this type name
             replaceText -- if not None, replace a match with this string
         """
-        QApplication.setOverrideCursor(Qt.WaitCursor)
+        QApplication.setOverrideCursor(Qt.CursorShape.WaitCursor)
         dataUndo = undo.DataUndo(self.structure.undoList,
                                  self.structure.childList, addBranch=True)
         totalMatches = 0
@@ -1686,7 +1721,11 @@ class TreeLocalControl(QObject):
         self.updateWindowCaptions()
         oldControl = globalref.mainControl.activeControl
         if oldControl:
-            oldControl.activeWindow.saveWindowGeom()
+            try:
+                oldControl.activeWindow.saveWindowGeom()
+            except RuntimeError:
+                # possibly avoid rare error of deleted c++ TreeWindow
+                pass
         window.restoreWindowGeom(offset)
         self.activeWindow = window
         self.expandRootNodes()
